@@ -1,4 +1,5 @@
 import sys
 import StrawEngine
 sys.path.append(StrawEngine.__file__[::-1].split("/",1)[1][::-1])
-from StrawEngine.straw import main
+from StrawEngine.straw import main as mainapi
+main = lambda: mainapi(sys.argv, True)
\ No newline at end of file
