@@ -1,4 +1,6 @@
-def readfile_(command, blocks, preprocessed):
+COMMAND = "@readfile"
+
+def run(command, blocks, preprocessed):
     if command.parms:
         with open(command.parms[0], "r") as file:
             return file.read()
\ No newline at end of file
